==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pl/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.4 (2004083100)


$string['addcomment'] = 'Dodaj komentarz';
$string['addentry'] = 'Dodaj pojcie';
$string['addingcomment'] = 'Dodaj komentarz';
$string['aliases'] = 'Sowo kluczowe';
$string['allcategories'] = 'Wszystkie kategorie';
$string['allentries'] = 'Wszystkie';
$string['allowcomments'] = 'Pozwl komentowa wpisy';
$string['allowduplicatedentries'] = 'Pozwl na wielokrotne definiowanie tego samego pojcia';
$string['allowratings'] = 'Czy chcesz aby wpisy byy oceniane?';
$string['answer'] = 'Odpowied';
$string['approve'] = 'Potwierd';
$string['areyousuredelete'] = 'Czy jeste pewien e chcesz to usun?';
$string['areyousuredeletecomment'] = 'Czy jeste pewien e chcesz to usun?';
$string['areyousureexport'] = 'Czy jeste pewien e chcesz wyeksportowa ten wpis do';
$string['ascending'] = 'Wzrastajco';
$string['attachment'] = 'Zacznik';
$string['authorview'] = 'Szukaj wedug autora';
$string['back'] = 'Powrt';
$string['cantinsertcat'] = 'Nie mona wstawi tej kategorii';
$string['cantinsertrec'] = 'Nie mona wstawi rekordu';
$string['cantinsertrel'] = 'Nie mona wstawi relacji kategoria-wpis';
$string['casesensitive'] = 'Ten wpis inaczej traktuje due i mae litery';
$string['categories'] = 'Kategorie';
$string['category'] = 'Kategoria';
$string['categorydeleted'] = 'Usunita kategoria';
$string['categoryview'] = 'Szukaj wedug kategorii';
$string['cnfallowcomments'] = 'Okrel czy sownik poj domylnie zaakceptuje komentarze.';
$string['cnfallowdupentries'] = 'Okrel czy sownik poj domylnie pozwoli na podwjne definicje.';
$string['cnfapprovalstatus'] = 'Okrel czy wpis dokonany przez studenta bdzie domylnie aprobowany.';
$string['cnfcasesensitive'] = 'Okrel czy domylnie nowy wpis w sytuacji kiedy jest automatycznie czony z innymi wpisami, pozostaje wraliwy na due i mae litery.';
$string['cnfdefaulthook'] = 'Okrel domylne znaznaczenie, kiedy sownik bdzie otwarty po raz pierwszy.';
$string['cnfdefaultmode'] = 'Wybierz domyln ramk, ktra si pojawi gdy sownik poj bdzie po raz pierwszy uruchomiony.';
$string['cnffullmatch'] = 'Okrel, czy wpis, ktry jest automatycznie poczony z docelowym wyrazem, powinien zaczyna si tak liter jak wyraz docelowy.';
$string['cnflinkentry'] = 'Okrel czy wpis domylnie powinien by automatycznie poczony z docelowym wyrazem.';
$string['cnflinkglossaries'] = 'Okrel czy sownik poj powinien by automatycznie czony z innymi wpisami.';
$string['cnfrelatedview'] = 'Wybierz format wywietlenia wpisw dla automatycznego czenia poj i wywietlenia wpisu';
$string['cnfshowgroup'] = 'Okrel czy przerwa powinna by widoczna czy nie';
$string['cnfsortkey'] = 'Wybierz domylny klucz sortowania';
$string['cnfsortorder'] = 'Wybierz domylny sposb sortowania';
$string['cnfstudentcanpost'] = 'Okrel czy studenci mog czy nie mog wprowadza nowych poj.';
$string['comment'] = 'Komentarz';
$string['commentdeleted'] = 'Komentarz zosta usunity';
$string['comments'] = 'Komentarze';
$string['commentson'] = 'Komentarze na';
$string['commentupdated'] = 'Komentarz zosta uaktualniony';
$string['concept'] = 'Termin';
$string['concepts'] = 'Terminy';
$string['configenablerssfeeds'] = 'Umoliwia RSS feeds dla wszystkich sownikw poj. Musisz jednak i tak wczy obsug feeds manualnie dla kadego sownika.';
$string['currentglossary'] = 'Aktualny sownik poj';
$string['dateview'] = 'Szukaj wedug daty';
$string['defaultapproval'] = 'Automatycznie aprobuj wpisy definicji przez studentw';
$string['definition'] = 'Definicja';
$string['definitions'] = 'Definicje';
$string['deleteentry'] = 'Usu wpis';
$string['deletingcomment'] = 'Usuwanie komentarza';
$string['deletingnoneemptycategory'] = 'Usunicie tej kategorii nie spowoduje usunicia poj, ktre odwoyway si do tej kategorii. Pojcia te zostan oznaczone jako \"nieskategoryzowane\"';
$string['descending'] = 'Malejce';
$string['destination'] = 'Importuj do';
$string['displayformat'] = 'Format sownika';
$string['displayformatcontinuous'] = 'Cigy bez autora';
$string['displayformatdictionary'] = 'Prosty styl sownika';
$string['displayformatencyclopedia'] = 'Encyklopedia';
$string['displayformatentrylist'] = 'Lista wpisw';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Peny z autorami';
$string['displayformatfullwithoutauthor'] = 'Peny bez autorw';
$string['displayformats'] = 'Dostpne formaty wygldu';
$string['displayformatssetup'] = 'Wywietl ustawienia formatw';
$string['duplicateentry'] = 'Podwjne definicje';
$string['editalways'] = 'Zawsze mona edytowa';
$string['editcategories'] = 'Edytuj kategorie';
$string['editentry'] = 'Edytuj wpis';
$string['editingcomment'] = 'Edytuj komentarz';
$string['entbypage'] = 'Wywietl podan ilo poj na stronie';
$string['entries'] = 'Pojcia';
$string['entrieswithoutcategory'] = 'Pojcia nieskategoryzowane';
$string['entry'] = 'Pojcie';
$string['entryalreadyexist'] = 'Pojcie ju istnieje';
$string['entryapproved'] = 'Wpis zosta zaaprobowany';
$string['entrydeleted'] = 'Wpis zosta usunity';
$string['entryexported'] = 'Wpis zosta wyeksportowany';
$string['entryishidden'] = '(ten wpis jest aktualnie ukryty)';
$string['entryleveldefaultsettings'] = 'Domylne ustawienia wejciowe';
$string['entryusedynalink'] = 'Ten wpis powinien zosta automatycznie poczony z innymi wpisami w systemie';
$string['explainaddentry'] = 'Dodaj nowe pojcie do tego sownika poj.<br>Pola: Termin i Definicja musz zosta wypenione.';
$string['explainall'] = 'Wywietl wszystkie pojcia na jednej stronie';
$string['explainalphabet'] = 'Wyszukaj pojcia uywajc tego indeksu';
$string['explainexport'] = 'Plik zosta stworzony.<br>cignij go i zachowaj w bezpiecznym miejscu. Moesz go zaimportowa kiedy tylko chcesz w ramach tego czy innego kursu.';
$string['explainimport'] = 'Musisz wskaza plik, ktry chcesz importowa i zdefiniowac kryteria.<p>Wylij swoje danie i sprawd wynik.';
$string['explainspecial'] = 'Poka pojcia, ktre nie zaczynaj si od litery';
$string['exportedentry'] = 'Wyeksportowany plik';
$string['exportedfile'] = 'Eksportuj plik';
$string['exportentries'] = 'Eksportuj pojcia';
$string['exportglossary'] = 'Eksportuj sownik poj';
$string['exporttomainglossary'] = 'Eksportuj do gwnego sownika poj';
$string['filetoimport'] = 'Plik do importu';
$string['fillfields'] = 'Pola: Termin i Definicja musz zosta wypenione';
$string['filtername'] = 'Automatyczne linkowanie poj';
$string['fullmatch'] = 'Szukaj tylko wyrazw tak jak zostay wpisane<br><small>(jeli zostay automatycznie poczone)';
$string['globalglossary'] = 'Sownik globalny';
$string['glossaryleveldefaultsettings'] = 'Domylne ustawienia sownika';
$string['glossarytype'] = 'Typ sownika poj';
$string['glosssaryexported'] = 'Wyeksportowano sownik poj';
$string['importcategories'] = 'Importuj kategorie';
$string['importedcategories'] = 'Zaimportowano kategorie';
$string['importedentries'] = 'Zaimportowano wpisy';
$string['importentries'] = 'Importuj pojcia';
$string['isglobal'] = 'Czy to jest globalny sownik poj?';
$string['linkcategory'] = 'Automatycznie cz t kategori';
$string['mainglossary'] = 'Gwny sownik poj';
$string['maxtimehaspassed'] = 'Przepraszamy, ale maksymalny czas przeznaczony na edycje tego komentarza ($a) min!';
$string['modulename'] = 'Sownik poj';
$string['modulenameplural'] = 'Sowniki poj';
$string['newentries'] = 'Nowe wpisy w sowniku';
$string['newglossary'] = 'Nowy sownik poj';
$string['newglossarycreated'] = 'Nowy sownik poj zosta utworzony';
$string['newglossaryentries'] = 'Nowe pojcia w sowniku:';
$string['nocomment'] = 'Nie znaleziono adnych komentarzy';
$string['nocomments'] = '(Nie znaleziono adnych komentarzy dotyczcych tego wpisu)';
$string['noconceptfound'] = 'Nie znaleziono adnych terminw ani definicji';
$string['noentries'] = 'Nie znaleziono adnych poj w tej sekcji';
$string['noentry'] = 'Nie znaleziono adnych poj';
$string['notcategorised'] = 'Nieskategoryzowane';
$string['numberofentries'] = 'Ilo poj';
$string['onebyline'] = '(jedno na lini)';
$string['printerfriendly'] = 'Wersja do wydruku';
$string['question'] = 'Pytanie';
$string['rate'] = 'Ranking';
$string['rating'] = 'Ocena';
$string['ratingeveryone'] = 'Kady moe ocenia definicje';
$string['ratingno'] = 'Nie mona ocenia';
$string['ratingonlyteachers'] = 'Tylko $a moe ocenia definicje';
$string['ratings'] = 'Oceny';
$string['ratingssaved'] = 'Oceny zostay zapisane';
$string['ratingsuse'] = 'Uyj ocen';
$string['ratingtime'] = 'Ogranicz oceny do definicji wpisanych pomidzy tymi datami:';
$string['rejectedentries'] = 'Odrzu wpisy';
$string['rejectionrpt'] = 'Raport Odrzuce';
$string['rsssubscriberss'] = 'Wywietl RSS feed dla $a terminw';
$string['searchindefinition'] = 'Przeszukaj cay tekst';
$string['secondaryglossary'] = 'Tymczasowy sownik poj';
$string['sendinratings'] = 'Przylij moje ostatnie oceny';
$string['showall'] = 'Poka link &#8222;Wszystkie&#8221;';
$string['showalphabet'] = 'Poka link ';
$string['showspecial'] = 'Poka link &#8222;Specjalne&#8221;';
$string['sortby'] = 'Posortuj wedug';
$string['sortbycreation'] = 'Wedug daty utworzenia';
$string['sortbylastupdate'] = 'Wedug ostatniej aktualizacji';
$string['sortchronogically'] = 'Posortuj chronologicznie';
$string['special'] = 'Specjalne';
$string['standardview'] = 'Szukaj wedug alfabetu';
$string['studentcanpost'] = 'Studenci mog dodawa nowe pojcia';
$string['totalentries'] = 'Ilo wpisw';
$string['usedynalink'] = 'Automatycznie cz wpisane pojcia';
$string['waitingapproval'] = 'Oczekiwanie potwierdzenia';
$string['warningstudentcapost'] = '(Dotyczy tylko sytuacji gdy sownik poj nie jest sownikiem gwnym)';
$string['withauthor'] = 'Terminy z autorem';
$string['withoutauthor'] = 'Terminy bez autora';
$string['writtenby'] = 'przez';
$string['youarenottheauthor'] = 'Nie jeste autorem tego wpisu, tak wic nie moesz go edytowa.';

?>

==> moodle_1.5.3+20060108.orig.tar.gz: moodle/lang/pl/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.6 development (2005072200)


$string['addcomment'] = 'Dodaj komentarz';
$string['addentry'] = 'Dodaj pojcie';
$string['addingcomment'] = 'Dodaj komentarz';
$string['aliases'] = 'Sowo kluczowe';
$string['allcategories'] = 'Wszystkie kategorie';
$string['allentries'] = 'Wszystkie';
$string['allowcomments'] = 'Pozwl komentowa wpisy';
$string['allowduplicatedentries'] = 'Pozwl na wielokrotne definiowanie tego samego pojcia';
$string['allowprintview'] = 'Pozwl drukowa sownik';
$string['allowratings'] = 'Czy chcesz aby wpisy byy oceniane?';
$string['answer'] = 'Odpowied';
$string['approve'] = 'Potwierd';
$string['areyousuredelete'] = 'Czy jeste pewien e chcesz to usun?';
$string['areyousuredeletecomment'] = 'Czy jeste pewien e chcesz to usun?';
$string['areyousureexport'] = 'Czy jeste pewien e chcesz wyeksportowa ten wpis do';
$string['ascending'] = 'Wzrastajco';
$string['attachment'] = 'Zacznik';
$string['authorview'] = 'Szukaj wedug autora';
$string['back'] = 'Powrt';
$string['cantinsertcat'] = 'Nie mona wstawi tej kategorii';
$string['cantinsertrec'] = 'Nie mona wstawi rekordu';
$string['cantinsertrel'] = 'Nie mona wstawi relacji kategoria-wpis';
$string['casesensitive'] = 'Ten wpis inaczej traktuje due i mae litery';
$string['categories'] = 'Kategorie';
$string['category'] = 'Kategoria';
$string['categorydeleted'] = 'Usunita kategoria';
$string['categoryview'] = 'Szukaj wedug kategorii';
$string['cnfallowcomments'] = 'Okrel czy sownik poj domylnie zaakceptuje komentarze.';
$string['cnfallowdupentries'] = 'Okrel czy sownik poj domylnie pozwoli na podwjne definicje.';
$string['cnfapprovalstatus'] = 'Okrel czy wpis dokonany przez studenta bdzie domylnie aprobowany.';
$string['cnfcasesensitive'] = 'Okrel czy domylnie nowy wpis w sytuacji kiedy jest automatycznie czony z innymi wpisami, pozostaje wraliwy na due i mae litery.';
$string['cnfdefaulthook'] = 'Okrel domylne znaznaczenie, kiedy sownik bdzie otwarty po raz pierwszy.';
$string['cnfdefaultmode'] = 'Wybierz domyln ramk, ktra si pojawi gdy sownik poj bdzie po raz pierwszy uruchomiony.';
$string['cnffullmatch'] = 'Okrel, czy wpis, ktry jest automatycznie poczony z docelowym wyrazem, powinien zaczyna si tak liter jak wyraz docelowy.';
$string['cnflinkentry'] = 'Okrel czy wpis domylnie powinien by automatycznie poczony z docelowym wyrazem.';
$string['cnflinkglossaries'] = 'Okrel czy sownik poj powinien by automatycznie czony z innymi wpisami.';
$string['cnfrelatedview'] = 'Wybierz format wywietlenia wpisw dla automatycznego czenia poj i wywietlenia wpisu';
$string['cnfshowgroup'] = 'Okrel czy przerwa powinna by widoczna czy nie';
$string['cnfsortkey'] = 'Wybierz domylny klucz sortowania';
$string['cnfsortorder'] = 'Wybierz domylny sposb sortowania';
$string['cnfstudentcanpost'] = 'Okrel czy studenci mog czy nie mog wprowadza nowych poj.';
$string['comment'] = 'Komentarz';
$string['commentdeleted'] = 'Komentarz zosta usunity';
$string['comments'] = 'Komentarze';
$string['commentson'] = 'Komentarze na';
$string['commentupdated'] = 'Komentarz zosta uaktualniony';
$string['concept'] = 'Termin';
$string['concepts'] = 'Terminy';
$string['configenablerssfeeds'] = 'Umoliwia RSS feeds dla wszystkich sownikw poj. Musisz jednak i tak wczy obsug feeds manualnie dla kadego sownika.';
$string['currentglossary'] = 'Aktualny sownik poj';
$string['dateview'] = 'Szukaj wedug daty';
$string['defaultapproval'] = 'Automatycznie aprobuj wpisy definicji przez studentw';
$string['definition'] = 'Definicja';
$string['definitions'] = 'Definicje';
$string['deleteentry'] = 'Usu wpis';
$string['deletingcomment'] = 'Usuwanie komentarza';
$string['deletingnoneemptycategory'] = 'Usunicie tej kategorii nie spowoduje usunicia poj, ktre odwoyway si do tej kategorii. Pojcia te zostan oznaczone jako \"nieskategoryzowane\"';
$string['descending'] = 'Malejce';
$string['destination'] = 'Importuj do';
$string['displayformat'] = 'Format sownika';
$string['displayformatcontinuous'] = 'Cigy bez autora';
$string['displayformatdictionary'] = 'Prosty styl sownika';
$string['displayformatencyclopedia'] = 'Encyklopedia';
$string['displayformatentrylist'] = 'Lista wpisw';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Peny z autorami';
$string['displayformatfullwithoutauthor'] = 'Peny bez autorw';
$string['displayformats'] = 'Dostpne formaty wygldu';
$string['displayformatssetup'] = 'Wywietl ustawienia formatw';
$string['duplicateentry'] = 'Podwjne definicje';
$string['editalways'] = 'Zawsze mona edytowa';
$string['editcategories'] = 'Edytuj kategorie';
$string['editentry'] = 'Edytuj wpis';
$string['editingcomment'] = 'Edytuj komentarz';
$string['entbypage'] = 'Wywietl podan ilo poj na stronie';
$string['entries'] = 'Pojcia';
$string['entrieswithoutcategory'] = 'Pojcia nieskategoryzowane';
$string['entry'] = 'Pojcie';
$string['entryalreadyexist'] = 'Pojcie ju istnieje';
$string['entryapproved'] = 'Wpis zosta zaaprobowany';
$string['entrydeleted'] = 'Wpis zosta usunity';
$string['entryexported'] = 'Wpis zosta wyeksportowany';
$string['entryishidden'] = '(ten wpis jest aktualnie ukryty)';
$string['entryleveldefaultsettings'] = 'Domylne ustawienia wejciowe';
$string['entrysaved'] = 'Haso zostao zapisane';
$string['entryupdated'] = 'Haso zostao uaktualnione';
$string['entryusedynalink'] = 'Ten wpis powinien zosta automatycznie poczony z innymi wpisami w systemie';
$string['explainaddentry'] = 'Dodaj nowe pojcie do tego sownika poj.<br />Pola: Termin i Definicja musz zosta wypenione.';
$string['explainall'] = 'Wywietl wszystkie pojcia na jednej stronie';
$string['explainalphabet'] = 'Wyszukaj pojcia uywajc tego indeksu';
$string['explainexport'] = 'Plik zosta stworzony.<br />cignij go i zachowaj w bezpiecznym miejscu. Moesz go zaimportowa kiedy tylko chcesz w ramach tego czy innego kursu.';
$string['explainimport'] = 'Musisz wskaza plik, ktry chcesz importowa i zdefiniowac kryteria.<p>Wylij swoje danie i sprawd wynik.';
$string['explainspecial'] = 'Poka pojcia, ktre nie zaczynaj si od litery';
$string['exportedentry'] = 'Wyeksportowany plik';
$string['exportedfile'] = 'Eksportuj plik';
$string['exportentries'] = 'Eksportuj pojcia';
$string['exportglossary'] = 'Eksportuj sownik poj';
$string['exporttomainglossary'] = 'Eksportuj do gwnego sownika poj';
$string['filetoimport'] = 'Plik do importu';
$string['fillfields'] = 'Pola: Termin i Definicja musz zosta wypenione';
$string['filtername'] = 'Automatyczne linkowanie poj';
$string['fullmatch'] = 'Szukaj tylko wyrazw tak jak zostay wpisane<br /><small>(jeli zostay automatycznie poczone)</small>';
$string['globalglossary'] = 'Sownik globalny';
$string['glossaryleveldefaultsettings'] = 'Domylne ustawienia sownika';
$string['glossarytype'] = 'Typ sownika poj';
$string['glosssaryexported'] = 'Wyeksportowano sownik poj';
$string['importcategories'] = 'Importuj kategorie';
$string['importedcategories'] = 'Zaimportowano kategorie';
$string['importedentries'] = 'Zaimportowano wpisy';
$string['importentries'] = 'Importuj pojcia';
$string['isglobal'] = 'Czy to jest globalny sownik poj?';
$string['linkcategory'] = 'Automatycznie cz t kategori';
$string['mainglossary'] = 'Gwny sownik poj';
$string['maxtimehaspassed'] = 'Przepraszamy, ale maksymalny czas przeznaczony na edycje tego komentarza ($a) min!';
$string['modulename'] = 'Sownik poj';
$string['modulenameplural'] = 'Sowniki poj';
$string['newentries'] = 'Nowe wpisy w sowniku';
$string['newglossary'] = 'Nowy sownik poj';
$string['newglossarycreated'] = 'Nowy sownik poj zosta utworzony';
$string['newglossaryentries'] = 'Nowe pojcia w sowniku:';
$string['nocomment'] = 'Nie znaleziono adnych komentarzy';
$string['nocomments'] = '(Nie znaleziono adnych komentarzy dotyczcych tego wpisu)';
$string['noconceptfound'] = 'Nie znaleziono adnych terminw ani definicji';
$string['noentries'] = 'Nie znaleziono adnych poj w tej sekcji';
$string['noentry'] = 'Nie znaleziono adnych poj';
$string['notcategorised'] = 'Nieskategoryzowane';
$string['numberofentries'] = 'Ilo poj';
$string['onebyline'] = '(jedno na lini)';
$string['printerfriendly'] = 'Wersja do wydruku';
$string['printviewnotallowed'] = 'Nie pozwalaj na drukowanie sownika';
$string['question'] = 'Pytanie';
$string['rate'] = 'Ranking';
$string['rating'] = 'Ocena';
$string['ratingeveryone'] = 'Kady moe ocenia definicje';
$string['ratingno'] = 'Nie mona ocenia';
$string['ratingonlyteachers'] = 'Tylko $a moe ocenia definicje';
$string['ratings'] = 'Oceny';
$string['ratingssaved'] = 'Oceny zostay zapisane';
$string['ratingsuse'] = 'Uyj ocen';
$string['ratingtime'] = 'Ogranicz oceny do definicji wpisanych pomidzy tymi datami:';
$string['rejectedentries'] = 'Odrzu wpisy';
$string['rejectionrpt'] = 'Raport Odrzuce';
$string['rsssubscriberss'] = 'Wywietl RSS feed dla $a terminw';
$string['searchindefinition'] = 'Przeszukaj cay tekst';
$string['secondaryglossary'] = 'Tymczasowy sownik poj';
$string['sendinratings'] = 'Przylij moje ostatnie oceny';
$string['showall'] = 'Poka link &#8222;Wszystkie&#8221;';
$string['showalphabet'] = 'Poka link ';
$string['showspecial'] = 'Poka link &#8222;Specjalne&#8221;';
$string['sortby'] = 'Posortuj wedug';
$string['sortbycreation'] = 'Wedug daty utworzenia';
$string['sortbylastupdate'] = 'Wedug ostatniej aktualizacji';
$string['sortchronogically'] = 'Posortuj chronologicznie';
$string['special'] = 'Specjalne';
$string['standardview'] = 'Szukaj wedug alfabetu';
$string['studentcanpost'] = 'Studenci mog dodawa nowe pojcia';
$string['totalentries'] = 'Ilo wpisw';
$string['usedynalink'] = 'Automatycznie cz wpisane pojcia';
$string['waitingapproval'] = 'Oczekiwanie potwierdzenia';
$string['warningstudentcapost'] = '(Dotyczy tylko sytuacji gdy sownik poj nie jest sownikiem gwnym)';
$string['withauthor'] = 'Terminy z autorem';
$string['withoutauthor'] = 'Terminy bez autora';
$string['writtenby'] = 'przez';
$string['youarenottheauthor'] = 'Nie jeste autorem tego wpisu, tak wic nie moesz go edytowa.';

?>
